import React, { useState, useEffect, useMemo } from 'react';
import * as MUI from '@mui/material';
import MultiSelectText from './MultiSelectText';
import "../../Css/Search.css";
import * as externalSelections from './Selections'; // Import selections from external file

export const SearchComponent = ({ data, changeRegion }) => {

  const [selectedProvince, setSelectedProvince] = useState(null);

  const [parentSelection, setParentSelection] = useState(-1);

  const[component, setComponent]  = useState(null);

  const[components, setComponents] = useState(null);

  changeRegion(selectedProvince)


  let globalChildSelection = -1;

  /*
    Some temporary selection allocation
  */ 
  const euElection = externalSelections.euElection;
  const selections = externalSelections.selections;

/**
 * useEffect hook to update the selected province based on the incoming data.
 * If the incoming data matches any province option, it sets the selected province.
 * Otherwise, it sets the selected province to null.
 *
 * @param {string} data - The incoming data to check against province options.
 * @param {function} setSelectedProvince - Function to set the selected province state.
 */
  const provinceOptions = [
      'Stockholm', 'Uppsala', 'Södermanland', 'Östergötland', 'Jönköping',
      'Kronoberg', 'Kalmar', 'Gotland', 'Blekinge', 'Skåne', 'Halland',
      'Västra Götaland', 'Värmland', 'Örebro', 'Västmanland', 'Dalarna',
      'Gävleborg', 'Västernorrland', 'Jämtland', 'Västerbotten', 'Norrbotten'
  ];
  useEffect(() => {
    
    if (data && provinceOptions.includes(data)) {
      setSelectedProvince(data);
    } else {
      setSelectedProvince(null);
    }
  }, [data]);

  const handleProvinceChange = (event, newValue) => {
    setSelectedProvince(newValue);
  };

  const isOptionEqualToValue = (option, value) => option === value;

  const memoizedProvince = useMemo(() => selectedProvince, [selectedProvince]);


  function parentIndexHandler(index){
    const element = euElection.childrens[index];
    setParentSelection(element);
  };


  function level_1_indexHandler(index){
    console.log("childIndexHandler index:" + index)
    globalChildSelection = index;
  };

// Function to get the child selection based on the parent element
const handleChildSelection = () => {
  switch (parentSelection) {
    case 'a':
      setComponent( <div className='multi_select'><MultiSelectText selection={externalSelections.level_1_selections.level_1_1_selection} multiSelect={false} indexHandler={level_1_indexHandler}/><button onClick={handleComponentSelection}> Select</button></div>);
      break;
    case 'b':
      setComponent( <div className='multi_select'><MultiSelectText selection={externalSelections.level_1_selections.level_1_2_selection} multiSelect={false} indexHandler={level_1_indexHandler}/><button onClick={handleComponentSelection}> Select</button></div>);
      break;
    case 'c':
      setComponent( <div className='multi_select'><MultiSelectText selection={externalSelections.level_1_selections.level_1_3_selection} multiSelect={false} indexHandler={level_1_indexHandler}/><button onClick={handleComponentSelection}> Select</button></div>);
      break;
    default:
      setComponent(null);
  }
};

const handleComponentSelection = () => {
  console.log("handleComponentSelection:, global:;" +globalChildSelection)
  const selected = {};

  for (const [key, value] of Object.entries(selections)) {
    if (value.id.includes(globalChildSelection)) {
      selected[key] = value;
    }
  }



  setComponents( 
     <div>
      {Object.values(selected).map((selection, index) => (
        <div key={index} className='multi_select'>
          <MultiSelectText selection={selection} multiSelect={true} />
        </div>
      ))}
      </div>
  );
};


return (
    <div>
      <MUI.Autocomplete  
        disablePortal
        id="combo-box-demo"
        options={provinceOptions}
        value={memoizedProvince}
        onChange={handleProvinceChange}
        getOptionSelected={isOptionEqualToValue} // Custom equality test
        sx={{ 
          width: 350,
          marginTop: "15px",
          '& .MuiInputBase-root': {
            backgroundColor: '#3D96B1', // Ensure background color applies to the input itself
            color: "#061525",
            fontSize: "20px",
            marginTop: "20px",
            fontFamily: "source-code-pro, Menlo, Monaco, Consolas, 'Courier New', monospace;"
          },
          '& .MuiButtonBase-root svg' : {
            background: "#061525",

          },
          '& .MuiOutlinedInput-root' : {
            border: "1px solid white" //Ensure smooth transitions between borders
          },
          '& .MuiOutlinedInput-notchedOutline' : {
            display: "none", //Remove the notched border
          },
          '& .MuiOutlinedInput-root.Mui-focused' : {
            border: "1px solid white"
          },
          '& .MuiOutlinedInput-root:hover' : {
            border: "1px solid white"
          },
          '& .MuiButtonBase-root' : {
            color: "white",
          }
        }}
        renderInput={(params) => (
          <MUI.TextField 
              {...params} 
              label="County"
              InputLabelProps={{
                sx: {
                  fontSize: '36px', // Change font size of the label
                  fontFamily: "source-code-pro, Menlo, Monaco, Consolas, 'Courier New', monospace;",
                  fontWeight: 700,

                  color: "white",
                  marginTop: '10px',
                  transform: 'translateY(-44px) scale(1)',
                  '&.Mui-focused': {color:"#3D96B1",
                                    fontSize: '36px',
                                    transform: 'translateY(-44px) scale(1)', // Move the label further up
                  },
                  
                  '&.MuiInputLabel-shrink' : {transform: 'translateY(-44px) scale(1)', // Move the label further up
                                              fontSize: '36px',
                  },                
                },
              }}
          />
        )}
      />

      
      <div className='multi_select'><MultiSelectText selection={euElection} multiSelect={false} indexHandler={parentIndexHandler}/>
        <button onClick={handleChildSelection}>Select</button>
      </div>

      <>{component}</>
      <>{components}</>
    </div>  
  );
};

export default SearchComponent;
